==> jc-1.4.0.tar.gz: soot/PatchingChain__24PatchingIterator.h <==
// public class soot.PatchingChain$PatchingIterator

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class e23193c43f62eec3 soot_PatchingChain__24PatchingIterator

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_soot_PatchingChain__24PatchingIterator_H_
#define _JC_soot_PatchingChain__24PatchingIterator_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_util_Iterator$object;
struct _jc_soot_PatchingChain$object;
struct _jc_soot_util_Chain$object;

// Typedefs
typedef struct _jc_soot_PatchingChain__24PatchingIterator$sub_refs	_jc_soot_PatchingChain__24PatchingIterator$sub_refs;
typedef struct _jc_soot_PatchingChain__24PatchingIterator$sub_nonrefs	_jc_soot_PatchingChain__24PatchingIterator$sub_nonrefs;
typedef struct _jc_soot_PatchingChain__24PatchingIterator$refs	_jc_soot_PatchingChain__24PatchingIterator$refs;
typedef struct _jc_soot_PatchingChain__24PatchingIterator$nonrefs	_jc_soot_PatchingChain__24PatchingIterator$nonrefs;
typedef struct _jc_soot_PatchingChain__24PatchingIterator$object	_jc_soot_PatchingChain__24PatchingIterator$object;

typedef const struct _jc_soot_PatchingChain__24PatchingIterator$vmethods	_jc_soot_PatchingChain__24PatchingIterator$vmethods;
typedef const struct _jc_soot_PatchingChain__24PatchingIterator$vtable	_jc_soot_PatchingChain__24PatchingIterator$vtable;
typedef const struct _jc_soot_PatchingChain__24PatchingIterator$vtype	_jc_soot_PatchingChain__24PatchingIterator$vtype;

// Constructors
extern void _jc_soot_PatchingChain__24PatchingIterator$method$_init$7b9af7cfdca0a262(_jc_env *, struct _jc_soot_PatchingChain__24PatchingIterator$object *, struct _jc_soot_PatchingChain$object *, struct _jc_object *);
extern void _jc_soot_PatchingChain__24PatchingIterator$method$_init$dc78c8ce1dde2d93(_jc_env *, struct _jc_soot_PatchingChain__24PatchingIterator$object *, struct _jc_soot_PatchingChain$object *, struct _jc_object *, struct _jc_java_lang_Object$object *);
extern void _jc_soot_PatchingChain__24PatchingIterator$method$_init$df1e76bc303a0740(_jc_env *, struct _jc_soot_PatchingChain__24PatchingIterator$object *, struct _jc_soot_PatchingChain$object *, struct _jc_object *, struct _jc_java_lang_Object$object *, struct _jc_java_lang_Object$object *);

// Virtual methods
extern jboolean _jc_soot_PatchingChain__24PatchingIterator$method$hasNext$fb0bd5e38c59ddcd(_jc_env *, struct _jc_soot_PatchingChain__24PatchingIterator$object *);
extern struct _jc_java_lang_Object$object *_jc_soot_PatchingChain__24PatchingIterator$method$next$05874f79a1cf66ea(_jc_env *, struct _jc_soot_PatchingChain__24PatchingIterator$object *);
extern void _jc_soot_PatchingChain__24PatchingIterator$method$remove$fd50149979e1f350(_jc_env *, struct _jc_soot_PatchingChain__24PatchingIterator$object *);

// Virtual method descriptors
extern _jc_method _jc_soot_PatchingChain__24PatchingIterator$method_info$hasNext$fb0bd5e38c59ddcd;
extern _jc_method _jc_soot_PatchingChain__24PatchingIterator$method_info$next$05874f79a1cf66ea;
extern _jc_method _jc_soot_PatchingChain__24PatchingIterator$method_info$remove$fd50149979e1f350;

// Virtual methods structure
struct _jc_soot_PatchingChain__24PatchingIterator$vmethods {
	jboolean	(*hasNext$fb0bd5e38c59ddcd)(_jc_env *, struct _jc_soot_PatchingChain__24PatchingIterator$object *);
	struct _jc_java_lang_Object$object	*(*next$05874f79a1cf66ea)(_jc_env *, struct _jc_soot_PatchingChain__24PatchingIterator$object *);
	void	(*remove$fd50149979e1f350)(_jc_env *, struct _jc_soot_PatchingChain__24PatchingIterator$object *);
};

// Vtable
struct _jc_soot_PatchingChain__24PatchingIterator$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_PatchingChain__24PatchingIterator$vmethods	soot_PatchingChain__24PatchingIterator;
};

// Vtype
struct _jc_soot_PatchingChain__24PatchingIterator$vtype {
	_jc_type			type;
	_jc_soot_PatchingChain__24PatchingIterator$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_PatchingChain__24PatchingIterator$sub_refs {
	struct _jc_object	*innerIterator;
	struct _jc_java_lang_Object$object	*lastObject;
	struct _jc_soot_PatchingChain$object	*this__240;
};

// Reference instance fields (object)
struct _jc_soot_PatchingChain__24PatchingIterator$refs {
    _jc_soot_PatchingChain__24PatchingIterator$sub_refs	soot_PatchingChain__24PatchingIterator;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_PatchingChain__24PatchingIterator$sub_nonrefs {
	jboolean	state;
};

// Non-reference instance fields (object)
struct _jc_soot_PatchingChain__24PatchingIterator$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_PatchingChain__24PatchingIterator$sub_nonrefs	soot_PatchingChain__24PatchingIterator;
};

// Object instance structure
struct _jc_soot_PatchingChain__24PatchingIterator$object {
	_jc_soot_PatchingChain__24PatchingIterator$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_PatchingChain__24PatchingIterator$vtype	*vtype;
	_jc_soot_PatchingChain__24PatchingIterator$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_PatchingChain__24PatchingIterator$vtype _jc_soot_PatchingChain__24PatchingIterator$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_PatchingChain__24PatchingIterator, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_PatchingChain__24PatchingIterator$class_object;

#endif	/* _JC_soot_PatchingChain__24PatchingIterator_H_ */

==> jc-1.4.6.tar.gz: soot/PatchingChain__24PatchingIterator.h <==
// public class soot.PatchingChain$PatchingIterator

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class e23193c43f62eec3 soot_PatchingChain__24PatchingIterator

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_soot_PatchingChain__24PatchingIterator_H_
#define _JC_soot_PatchingChain__24PatchingIterator_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_util_Iterator$object;
struct _jc_soot_PatchingChain$object;
struct _jc_soot_util_Chain$object;

// Typedefs
typedef struct _jc_soot_PatchingChain__24PatchingIterator$sub_refs	_jc_soot_PatchingChain__24PatchingIterator$sub_refs;
typedef struct _jc_soot_PatchingChain__24PatchingIterator$sub_nonrefs	_jc_soot_PatchingChain__24PatchingIterator$sub_nonrefs;
typedef struct _jc_soot_PatchingChain__24PatchingIterator$refs	_jc_soot_PatchingChain__24PatchingIterator$refs;
typedef struct _jc_soot_PatchingChain__24PatchingIterator$nonrefs	_jc_soot_PatchingChain__24PatchingIterator$nonrefs;
typedef struct _jc_soot_PatchingChain__24PatchingIterator$object	_jc_soot_PatchingChain__24PatchingIterator$object;

typedef const struct _jc_soot_PatchingChain__24PatchingIterator$vmethods	_jc_soot_PatchingChain__24PatchingIterator$vmethods;
typedef const struct _jc_soot_PatchingChain__24PatchingIterator$vtable	_jc_soot_PatchingChain__24PatchingIterator$vtable;
typedef const struct _jc_soot_PatchingChain__24PatchingIterator$vtype	_jc_soot_PatchingChain__24PatchingIterator$vtype;

// Constructors
extern void _jc_soot_PatchingChain__24PatchingIterator$method$_init$7b9af7cfdca0a262(_jc_env *, struct _jc_soot_PatchingChain__24PatchingIterator$object *, struct _jc_soot_PatchingChain$object *, struct _jc_object *) _JC_JCNI_ATTR;
extern void _jc_soot_PatchingChain__24PatchingIterator$method$_init$dc78c8ce1dde2d93(_jc_env *, struct _jc_soot_PatchingChain__24PatchingIterator$object *, struct _jc_soot_PatchingChain$object *, struct _jc_object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
extern void _jc_soot_PatchingChain__24PatchingIterator$method$_init$df1e76bc303a0740(_jc_env *, struct _jc_soot_PatchingChain__24PatchingIterator$object *, struct _jc_soot_PatchingChain$object *, struct _jc_object *, struct _jc_java_lang_Object$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;

// Virtual methods
extern jboolean _jc_soot_PatchingChain__24PatchingIterator$method$hasNext$fb0bd5e38c59ddcd(_jc_env *, struct _jc_soot_PatchingChain__24PatchingIterator$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_Object$object *_jc_soot_PatchingChain__24PatchingIterator$method$next$05874f79a1cf66ea(_jc_env *, struct _jc_soot_PatchingChain__24PatchingIterator$object *) _JC_JCNI_ATTR;
extern void _jc_soot_PatchingChain__24PatchingIterator$method$remove$fd50149979e1f350(_jc_env *, struct _jc_soot_PatchingChain__24PatchingIterator$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_PatchingChain__24PatchingIterator$method_info$hasNext$fb0bd5e38c59ddcd;
extern _jc_method _jc_soot_PatchingChain__24PatchingIterator$method_info$next$05874f79a1cf66ea;
extern _jc_method _jc_soot_PatchingChain__24PatchingIterator$method_info$remove$fd50149979e1f350;

// Virtual methods structure
struct _jc_soot_PatchingChain__24PatchingIterator$vmethods {
	jboolean	(*hasNext$fb0bd5e38c59ddcd)(_jc_env *, struct _jc_soot_PatchingChain__24PatchingIterator$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_Object$object	*(*next$05874f79a1cf66ea)(_jc_env *, struct _jc_soot_PatchingChain__24PatchingIterator$object *) _JC_JCNI_ATTR;
	void	(*remove$fd50149979e1f350)(_jc_env *, struct _jc_soot_PatchingChain__24PatchingIterator$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_PatchingChain__24PatchingIterator$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_PatchingChain__24PatchingIterator$vmethods	soot_PatchingChain__24PatchingIterator;
};

// Vtype
struct _jc_soot_PatchingChain__24PatchingIterator$vtype {
	_jc_type			type;
	_jc_soot_PatchingChain__24PatchingIterator$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_PatchingChain__24PatchingIterator$sub_refs {
	struct _jc_object	*innerIterator;
	struct _jc_java_lang_Object$object	*lastObject;
	struct _jc_soot_PatchingChain$object	*this__240;
};

// Reference instance fields (object)
struct _jc_soot_PatchingChain__24PatchingIterator$refs {
    _jc_soot_PatchingChain__24PatchingIterator$sub_refs	soot_PatchingChain__24PatchingIterator;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_PatchingChain__24PatchingIterator$sub_nonrefs {
	jboolean	state;
};

// Non-reference instance fields (object)
struct _jc_soot_PatchingChain__24PatchingIterator$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_PatchingChain__24PatchingIterator$sub_nonrefs	soot_PatchingChain__24PatchingIterator;
};

// Object instance structure
struct _jc_soot_PatchingChain__24PatchingIterator$object {
	_jc_soot_PatchingChain__24PatchingIterator$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_PatchingChain__24PatchingIterator$vtype	*vtype;
	_jc_soot_PatchingChain__24PatchingIterator$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_PatchingChain__24PatchingIterator$vtype _jc_soot_PatchingChain__24PatchingIterator$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_PatchingChain__24PatchingIterator, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_PatchingChain__24PatchingIterator$class_object;

#endif	/* _JC_soot_PatchingChain__24PatchingIterator_H_ */
